@@ -1,12 +1,14 @@
-package OpenResty;
+package OpenResty::Handler::Action;
 
 #use Smart::Comments;
 use strict;
 use warnings;
-use vars qw($Dumper);
+
+use OpenResty::Util;
+use Params::Util qw( _HASH _STRING );
 
 sub POST_action_exec {
-    my ($self, $bits) = @_;
+    my ($self, $openresty, $bits) = @_;
     my $action = $bits->[1];
     my $params = {
         $bits->[2] => $bits->[3]
@@ -18,34 +20,34 @@ sub POST_action_exec {
     if (lc($lang) ne 'minisql') {
         die "Only the miniSQL language is supported for Select.\n";
     }
-    my $sql = $self->{_req_data};
+    my $sql = $openresty->{_req_data};
     ### Action sql: $sql
 
     _STRING($sql) or
-        die "miniSQL must be an non-empty literal string: ", $Dumper->($sql), "\n";
+        die "miniSQL must be an non-empty literal string: ", $OpenResty::Dumper->($sql), "\n";
    #warn "SQL 1: $sql\n";
     my $select = OpenResty::MiniSQL::Select->new;
     my $res = $select->parse(
         $sql,
         {
             quote => \&Q, quote_ident => \&QI,
-            limit => $self->{_limit}, offset => $self->{_offset}
+            limit => $openresty->{_limit}, offset => $openresty->{_offset}
         }
     );
     if (_HASH($res)) {
         my $sql = $res->{sql};
-        $sql = $self->append_limit_offset($sql, $res);
+        $sql = $self->append_limit_offset($openresty, $sql, $res);
         my @models = @{ $res->{models} };
         my @cols = @{ $res->{columns} };
-        $self->validate_model_names(\@models);
-        $self->validate_col_names(\@models, \@cols);
+        $self->validate_model_names($openresty, \@models);
+        $self->validate_col_names($openresty, \@models, \@cols);
        #warn "SQL 2: $sql\n";
-        $self->select("$sql", {use_hash => 1, read_only => 1});
+        $openresty->select("$sql", {use_hash => 1, read_only => 1});
     }
 }
 
 sub append_limit_offset {
-    my ($self, $sql, $res) = @_;
+    my ($self, $openresty, $sql, $res) = @_;
     #my $order_by $cgi->url
     my $limit = $res->{limit};
     if (defined $limit) {
@@ -61,17 +63,17 @@ sub append_limit_offset {
 }
 
 sub validate_model_names {
-    my ($self, $models) = @_;
+    my ($self, $openresty, $models) = @_;
     for my $model (@$models) {
         _IDENT($model) or die "Bad model name: \"$model\"\n";
-        if (!$self->has_model($model)) {
+        if (!$openresty->has_model($model)) {
             die "Model \"$model\" not found.\n";
         }
     }
 }
 
 sub validate_col_names {
-    my ($self, $models, $cols) = @_;
+    my ($self, $openresty, $models, $cols) = @_;
     # XXX TODO...
 }
 
